# -*- coding: utf-8 -*-
import sys, json, re
from bs4 import BeautifulSoup
try:
    from urllib2 import urlopen
except ImportError:
    from urllib.request import urlopen
try:
    from urlparse import urlparse, parse_qs, urljoin
except ImportError:
    from urllib.parse import urlparse, parse_qs, urljoin
try:
    from urllib import urlencode
except ImportError:
    from urllib.parse import urlencode


def gethttp(url):
    return urlopen(url).read().decode('utf-8')


def getsoup(url):
    if (2, 7, 3) <= sys.version_info < (3, 0) or (3, 2) <= sys.version_info < (4, 0):
        return BeautifulSoup(urlopen(url), 'html.parser')
    return BeautifulSoup(urlopen(url), 'html5lib')


def getjson(url):
    return json.load(urlopen(url))


def play(url):
    try:
        content = gethttp(url)
    except Exception as e:
        return {'code': 'cntv 100', 'error': str(e)}
    videoCenterId = re.search(r'"videoCenterId","(.*?)"', content)
    if not videoCenterId:
        # https://tv.cctv.com/2020/12/25/VIDEyNuynsUg8A8JtgtfHY55201225.shtml
        videoCenterId = re.search(r'guid = "(.*?)"', content)
        if not videoCenterId:
            return {'code': 'cntv 101'}
    videoCenterId = videoCenterId.group(1)
    url = 'http://vdn.apps.cntv.cn/api/getHttpVideoInfo.do?pid=' + videoCenterId
    try:
        data = getjson(url)
    except Exception as e:
        return {'code': 'cntv 102', 'error': str(e)}
    try:
        return {data['title']: data['hls_url']}
    except Exception as e:
        return {'code': 'cntv 103', 'error': str(e)}

def videolist(url):
    o = urlparse(url)
    q = parse_qs(o.query)
    # url = 'http://api.cntv.cn/NewVideo/getVideoListByColumn?id=%s&n=30&sort=desc&p=1&mode=0&serviceId=tvcctv' % id
    url = 'http://api.cntv.cn/lanmu/videolistByColumnId?id=%s&serviceId=tvcctv&type=0&n=36&p=%s&t=json' % (q['id'][0], q['p'][0])
    try:
        data = getjson(url)
    except Exception as e:
        return {'code': 'cntv 400', 'error': str(e)}
    items = []
    for elem in data['response']['docs']:
        items.append({'title': elem['videoTitle'], 'img': elem['videoKeyFrameUrl'], 'url': elem['videoUrl'], 'plot': elem['videoBrief']})
    url = 'http://api.cntv.cn/lanmu/videolistByColumnId?id=%s&serviceId=tvcctv&type=0&n=36&p=%d&t=json' % (q['id'][0], int(q['p'][0]) + 1)
    items.append({'next': url})
    return items


def lm(url):
    try:
        content = gethttp(url)
    except Exception as e:
        return {'code': 'cntv 300', 'error': str(e)}
    id = re.search(r'api\.cntv\.cn/lanmu/videolistByColumnId\?id=(.*?)&', content, re.DOTALL)
    if not id:
        return {'code': 'cntv 301'}
    id = id.group(1)
    var = re.search(r'\s*\'\s*\+\s*(.*?)\s*\+\s*\'\s*', id)
    if var:
        var = var.group(1)
        id = re.search(var + '\s*=\s*\'(.*?)\'', content, re.DOTALL)
        if not id:
            return {'code': 'cntv 302'}
        id = id.group(1)
    url = 'http://api.cntv.cn/lanmu/videolistByColumnId?id=%s&serviceId=tvcctv&type=0&n=36&p=1&t=json' % id
    return videolist(url)


def vida(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'cntv 400', 'error': str(e)}
    items = []
    # http://tv.cctv.com/2017/08/01/VIDATpMb8AuFgveEQWuoBhJN170801.shtml
    for e in soup.select('div.list_box dd div.img a img'):
        items.append({'title': e.parent['title'], 'img': e['lazy'], 'url': urljoin(url, e.parent['href'])})
    # http://kejiao.cntv.cn/2012/12/15/VIDA1355519857003716.shtml
    for e in soup.select('ul#videolist li'):
        e1 = e.select('div.text h4 a')[0]
        e2 = e.select('div.image a img')[0]
        items.append({'title': e1.text, 'img': e2['src'], 'url': urljoin(url, e1['href'])})
    return items


def vset(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'cntv 400', 'error': str(e)}
    items = []
    for e1 in soup.select('div.image_list ul li h3 a'):
        items.append({'title': e1.text, 'url': urljoin(url, e1['href'])})
    # http://tv.cntv.cn/videoset/VSET100169831220
    for e1 in soup.select('div.list_box dd div.img a img'):
        items.append({'title': e1.parent['title'], 'img': e1['lazy'], 'url': urljoin(url, e1.parent['href'])})
    e1 = soup.select('div.page a.pre')
    if e1:
        items.append({'Next': urljoin(url, e1[0]['href'])})
    return items
